SheetStatus class

Constructors

SheetStatus({required double positionY, required double height, required double minHeight, required double maxHeight})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
final
isCollapsed → bool
no setter
isExpanded → bool
no setter
isOpened → bool
no setter
maxHeight → double
final
minHeight → double
final
positionY → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited